"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const api = require("../../../scw/api.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const resourcePaginator = require("../../../scw/fetch/resource-paginator.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class ContractAPI extends api.API {
  /**
   * Download a contract content.
   *
   * @param request - The request
   *   {@link ContractApiDownloadContractSignatureRequest}
   * @returns A Promise of Blob
   */
  downloadContractSignature = (request) => this.client.fetch({
    method: "GET",
    path: `/account/v3/contract-signatures/${marshalling.validatePathParam("contractSignatureId", request.contractSignatureId)}/download`,
    urlParams: marshalling.urlParams(["dl", 1], ["locale", request.locale]),
    responseType: "blob"
  });
  /**
   * Create a signature for your Organization for the latest version of the
   * requested contract.
   *
   * @param request - The request
   *   {@link ContractApiCreateContractSignatureRequest}
   * @returns A Promise of ContractSignature
   */
  createContractSignature = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalContractApiCreateContractSignatureRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/contract-signatures`
    },
    marshalling_gen.unmarshalContractSignature
  );
  /**
   * Sign a contract for your Organization.
   *
   * @param request - The request
   *   {@link ContractApiValidateContractSignatureRequest}
   * @returns A Promise of ContractSignature
   */
  validateContractSignature = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/contract-signatures/${marshalling.validatePathParam("contractSignatureId", request.contractSignatureId)}/validate`
    },
    marshalling_gen.unmarshalContractSignature
  );
  /**
   * Check if a contract is signed for your Organization.
   *
   * @param request - The request
   *   {@link ContractApiCheckContractSignatureRequest}
   * @returns A Promise of CheckContractSignatureResponse
   */
  checkContractSignature = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalContractApiCheckContractSignatureRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/contract-signatures/check`
    },
    marshalling_gen.unmarshalCheckContractSignatureResponse
  );
  pageOfListContractSignatures = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v3/contract-signatures`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListContractSignaturesResponse
  );
  /**
   * List contract signatures for an Organization.
   *
   * @param request - The request
   *   {@link ContractApiListContractSignaturesRequest}
   * @returns A Promise of ListContractSignaturesResponse
   */
  listContractSignatures = (request = {}) => resourcePaginator.enrichForPagination(
    "contractSignatures",
    this.pageOfListContractSignatures,
    request
  );
}
class ProjectAPI extends api.API {
  /**
   * Create a new Project for an Organization. Generate a new Project for an
   * Organization, specifying its configuration including name and description.
   *
   * @param request - The request {@link ProjectApiCreateProjectRequest}
   * @returns A Promise of Project
   */
  createProject = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalProjectApiCreateProjectRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/projects`
    },
    marshalling_gen.unmarshalProject
  );
  pageOfListProjects = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v3/projects`,
      urlParams: marshalling.urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_ids", request.projectIds]
      )
    },
    marshalling_gen.unmarshalListProjectsResponse
  );
  /**
   * List all Projects of an Organization. List all Projects of an Organization.
   * The response will include the total number of Projects as well as their
   * associated Organizations, names, and IDs. Other information includes the
   * creation and update date of the Project.
   *
   * @param request - The request {@link ProjectApiListProjectsRequest}
   * @returns A Promise of ListProjectsResponse
   */
  listProjects = (request = {}) => resourcePaginator.enrichForPagination("projects", this.pageOfListProjects, request);
  /**
   * Get an existing Project. Retrieve information about an existing Project,
   * specified by its Project ID. Its full details, including ID, name and
   * description, are returned in the response object.
   *
   * @param request - The request {@link ProjectApiGetProjectRequest}
   * @returns A Promise of Project
   */
  getProject = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v3/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
    },
    marshalling_gen.unmarshalProject
  );
  /**
   * Delete an existing Project. Delete an existing Project, specified by its
   * Project ID. The Project needs to be empty (meaning there are no resources
   * left in it) to be deleted effectively. Note that deleting a Project is
   * permanent, and cannot be undone.
   *
   * @param request - The request {@link ProjectApiDeleteProjectRequest}
   */
  deleteProject = (request = {}) => this.client.fetch({
    method: "DELETE",
    path: `/account/v3/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
  });
  /**
   * Update Project. Update the parameters of an existing Project, specified by
   * its Project ID. These parameters include the name and description.
   *
   * @param request - The request {@link ProjectApiUpdateProjectRequest}
   * @returns A Promise of Project
   */
  updateProject = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalProjectApiUpdateProjectRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/account/v3/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
    },
    marshalling_gen.unmarshalProject
  );
  /**
   * Set project use case. Set the project use case for a new or existing
   * Project, specified by its Project ID. You can customize the use case, sub
   * use case, and architecture type you want to use in the Project.
   *
   * @param request - The request
   *   {@link ProjectApiSetProjectQualificationRequest}
   * @returns A Promise of ProjectQualification
   */
  setProjectQualification = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalProjectApiSetProjectQualificationRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}/project-qualification`
    },
    marshalling_gen.unmarshalProjectQualification
  );
}
exports.ContractAPI = ContractAPI;
exports.ProjectAPI = ProjectAPI;
