import { API as API$1 } from "../../../scw/api.js";
import { validatePathParam, urlParams } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
import { enrichForPagination } from "../../../scw/fetch/resource-paginator.js";
import { marshalContractApiCreateContractSignatureRequest, unmarshalContractSignature, marshalContractApiCheckContractSignatureRequest, unmarshalCheckContractSignatureResponse, unmarshalListContractSignaturesResponse, marshalProjectApiCreateProjectRequest, unmarshalProject, unmarshalListProjectsResponse, marshalProjectApiUpdateProjectRequest, marshalProjectApiSetProjectQualificationRequest, unmarshalProjectQualification } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class ContractAPI extends API$1 {
  /**
   * Download a contract content.
   *
   * @param request - The request
   *   {@link ContractApiDownloadContractSignatureRequest}
   * @returns A Promise of Blob
   */
  downloadContractSignature = (request) => this.client.fetch({
    method: "GET",
    path: `/account/v3/contract-signatures/${validatePathParam("contractSignatureId", request.contractSignatureId)}/download`,
    urlParams: urlParams(["dl", 1], ["locale", request.locale]),
    responseType: "blob"
  });
  /**
   * Create a signature for your Organization for the latest version of the
   * requested contract.
   *
   * @param request - The request
   *   {@link ContractApiCreateContractSignatureRequest}
   * @returns A Promise of ContractSignature
   */
  createContractSignature = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalContractApiCreateContractSignatureRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/contract-signatures`
    },
    unmarshalContractSignature
  );
  /**
   * Sign a contract for your Organization.
   *
   * @param request - The request
   *   {@link ContractApiValidateContractSignatureRequest}
   * @returns A Promise of ContractSignature
   */
  validateContractSignature = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/contract-signatures/${validatePathParam("contractSignatureId", request.contractSignatureId)}/validate`
    },
    unmarshalContractSignature
  );
  /**
   * Check if a contract is signed for your Organization.
   *
   * @param request - The request
   *   {@link ContractApiCheckContractSignatureRequest}
   * @returns A Promise of CheckContractSignatureResponse
   */
  checkContractSignature = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalContractApiCheckContractSignatureRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/contract-signatures/check`
    },
    unmarshalCheckContractSignatureResponse
  );
  pageOfListContractSignatures = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v3/contract-signatures`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListContractSignaturesResponse
  );
  /**
   * List contract signatures for an Organization.
   *
   * @param request - The request
   *   {@link ContractApiListContractSignaturesRequest}
   * @returns A Promise of ListContractSignaturesResponse
   */
  listContractSignatures = (request = {}) => enrichForPagination(
    "contractSignatures",
    this.pageOfListContractSignatures,
    request
  );
}
class ProjectAPI extends API$1 {
  /**
   * Create a new Project for an Organization. Generate a new Project for an
   * Organization, specifying its configuration including name and description.
   *
   * @param request - The request {@link ProjectApiCreateProjectRequest}
   * @returns A Promise of Project
   */
  createProject = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalProjectApiCreateProjectRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/projects`
    },
    unmarshalProject
  );
  pageOfListProjects = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v3/projects`,
      urlParams: urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_ids", request.projectIds]
      )
    },
    unmarshalListProjectsResponse
  );
  /**
   * List all Projects of an Organization. List all Projects of an Organization.
   * The response will include the total number of Projects as well as their
   * associated Organizations, names, and IDs. Other information includes the
   * creation and update date of the Project.
   *
   * @param request - The request {@link ProjectApiListProjectsRequest}
   * @returns A Promise of ListProjectsResponse
   */
  listProjects = (request = {}) => enrichForPagination("projects", this.pageOfListProjects, request);
  /**
   * Get an existing Project. Retrieve information about an existing Project,
   * specified by its Project ID. Its full details, including ID, name and
   * description, are returned in the response object.
   *
   * @param request - The request {@link ProjectApiGetProjectRequest}
   * @returns A Promise of Project
   */
  getProject = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v3/projects/${validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
    },
    unmarshalProject
  );
  /**
   * Delete an existing Project. Delete an existing Project, specified by its
   * Project ID. The Project needs to be empty (meaning there are no resources
   * left in it) to be deleted effectively. Note that deleting a Project is
   * permanent, and cannot be undone.
   *
   * @param request - The request {@link ProjectApiDeleteProjectRequest}
   */
  deleteProject = (request = {}) => this.client.fetch({
    method: "DELETE",
    path: `/account/v3/projects/${validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
  });
  /**
   * Update Project. Update the parameters of an existing Project, specified by
   * its Project ID. These parameters include the name and description.
   *
   * @param request - The request {@link ProjectApiUpdateProjectRequest}
   * @returns A Promise of Project
   */
  updateProject = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalProjectApiUpdateProjectRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/account/v3/projects/${validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
    },
    unmarshalProject
  );
  /**
   * Set project use case. Set the project use case for a new or existing
   * Project, specified by its Project ID. You can customize the use case, sub
   * use case, and architecture type you want to use in the Project.
   *
   * @param request - The request
   *   {@link ProjectApiSetProjectQualificationRequest}
   * @returns A Promise of ProjectQualification
   */
  setProjectQualification = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalProjectApiSetProjectQualificationRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v3/projects/${validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}/project-qualification`
    },
    unmarshalProjectQualification
  );
}
export {
  ContractAPI,
  ProjectAPI
};
